==> haskell-aeson-better-errors-0.9.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.0.1
id: aeson-better-errors-0.9.0.1-ATwb1hR1PYJGLtod2p080E
key: aeson-better-errors-0.9.0.1-ATwb1hR1PYJGLtod2p080E
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: 3affd601e18ba522899958a56fc75fb4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-better-errors-0.9.0.1
hs-libraries: HSaeson-better-errors-0.9.0.1-ATwb1hR1PYJGLtod2p080E
depends:
    aeson-0.11.2.0-BJFBIG7cfak4WE0j2VGFvV base-4.9.0.0
    bytestring-0.10.8.1 dlist-0.8.0.1-8vOZASaQM8T5SLbodsdvHz
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.0.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.0.1
id: aeson-better-errors-0.9.0.1-3TmZOXgXxvhAeEZg6a4aqS
key: aeson-better-errors-0.9.0.1-3TmZOXgXxvhAeEZg6a4aqS
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: c3359b8ea1b17079abc86fac3416a2b0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-better-errors-0.9.0.1
hs-libraries: HSaeson-better-errors-0.9.0.1-3TmZOXgXxvhAeEZg6a4aqS
depends:
    aeson-0.11.2.0-1oWMNtvIfKMGa0C5QxOdH8 base-4.9.0.0
    bytestring-0.10.8.1 dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
